# coding: utf-8

# flake8: noqa

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.184.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "1.0.0"

# import apis into sdk package
from sonatype_iq_api_client.api.advanced_search_api import AdvancedSearchApi
from sonatype_iq_api_client.api.application_categories_api import ApplicationCategoriesApi
from sonatype_iq_api_client.api.application_report_data_api import ApplicationReportDataApi
from sonatype_iq_api_client.api.applications_api import ApplicationsApi
from sonatype_iq_api_client.api.audit_logs_api import AuditLogsApi
from sonatype_iq_api_client.api.auto_policy_waiver_revocations_api import AutoPolicyWaiverRevocationsApi
from sonatype_iq_api_client.api.auto_policy_waivers_api import AutoPolicyWaiversApi
from sonatype_iq_api_client.api.claim_components_api import ClaimComponentsApi
from sonatype_iq_api_client.api.components_api import ComponentsApi
from sonatype_iq_api_client.api.composite_source_control_api import CompositeSourceControlApi
from sonatype_iq_api_client.api.composite_source_control_validator_api import CompositeSourceControlValidatorApi
from sonatype_iq_api_client.api.config_artifactory_connection_api import ConfigArtifactoryConnectionApi
from sonatype_iq_api_client.api.config_crowd_api import ConfigCrowdApi
from sonatype_iq_api_client.api.config_jira_api import ConfigJIRAApi
from sonatype_iq_api_client.api.config_mail_api import ConfigMailApi
from sonatype_iq_api_client.api.config_proxy_server_api import ConfigProxyServerApi
from sonatype_iq_api_client.api.config_reverse_proxy_authentication_api import ConfigReverseProxyAuthenticationApi
from sonatype_iq_api_client.api.config_saml_api import ConfigSAMLApi
from sonatype_iq_api_client.api.config_source_control_api import ConfigSourceControlApi
from sonatype_iq_api_client.api.configuration_api import ConfigurationApi
from sonatype_iq_api_client.api.cyclone_dx_api import CycloneDXApi
from sonatype_iq_api_client.api.data_retention_policies_api import DataRetentionPoliciesApi
from sonatype_iq_api_client.api.developer_priorities_api import DeveloperPrioritiesApi
from sonatype_iq_api_client.api.endpoints_api import EndpointsApi
from sonatype_iq_api_client.api.feature_configuration_api import FeatureConfigurationApi
from sonatype_iq_api_client.api.firewall_api import FirewallApi
from sonatype_iq_api_client.api.labels_api import LabelsApi
from sonatype_iq_api_client.api.license_legal_metadata_api import LicenseLegalMetadataApi
from sonatype_iq_api_client.api.malware_api import MalwareApi
from sonatype_iq_api_client.api.organizations_api import OrganizationsApi
from sonatype_iq_api_client.api.policies_api import PoliciesApi
from sonatype_iq_api_client.api.policy_evaluation_api import PolicyEvaluationApi
from sonatype_iq_api_client.api.policy_violation_details_api import PolicyViolationDetailsApi
from sonatype_iq_api_client.api.policy_waiver_reasons_api import PolicyWaiverReasonsApi
from sonatype_iq_api_client.api.policy_waivers_api import PolicyWaiversApi
from sonatype_iq_api_client.api.reports_api import ReportsApi
from sonatype_iq_api_client.api.repositories_api import RepositoriesApi
from sonatype_iq_api_client.api.role_memberships_api import RoleMembershipsApi
from sonatype_iq_api_client.api.roles_api import RolesApi
from sonatype_iq_api_client.api.scan_api import ScanApi
from sonatype_iq_api_client.api.search_api import SearchApi
from sonatype_iq_api_client.api.security_overrides_api import SecurityOverridesApi
from sonatype_iq_api_client.api.solutions_api import SolutionsApi
from sonatype_iq_api_client.api.source_control_api import SourceControlApi
from sonatype_iq_api_client.api.source_control_metrics_api import SourceControlMetricsApi
from sonatype_iq_api_client.api.spdx_api import SpdxApi
from sonatype_iq_api_client.api.telemetry_api import TelemetryApi
from sonatype_iq_api_client.api.user_tokens_api import UserTokensApi
from sonatype_iq_api_client.api.users_api import UsersApi
from sonatype_iq_api_client.api.vulnerabilities_api import VulnerabilitiesApi
from sonatype_iq_api_client.api.sbom_api import SbomApi

# import ApiClient
from sonatype_iq_api_client.api_response import ApiResponse
from sonatype_iq_api_client.api_client import ApiClient
from sonatype_iq_api_client.configuration import Configuration
from sonatype_iq_api_client.exceptions import OpenApiException
from sonatype_iq_api_client.exceptions import ApiTypeError
from sonatype_iq_api_client.exceptions import ApiValueError
from sonatype_iq_api_client.exceptions import ApiKeyError
from sonatype_iq_api_client.exceptions import ApiAttributeError
from sonatype_iq_api_client.exceptions import ApiException

# import models into sdk package
from sonatype_iq_api_client.models.action import Action
from sonatype_iq_api_client.models.api_application_base_dto import ApiApplicationBaseDTO
from sonatype_iq_api_client.models.api_application_category_dto import ApiApplicationCategoryDTO
from sonatype_iq_api_client.models.api_application_dto import ApiApplicationDTO
from sonatype_iq_api_client.models.api_application_evaluation_commit_dto import ApiApplicationEvaluationCommitDTO
from sonatype_iq_api_client.models.api_application_evaluation_result_dtov2 import ApiApplicationEvaluationResultDTOV2
from sonatype_iq_api_client.models.api_application_evaluation_status_dtov2 import ApiApplicationEvaluationStatusDTOV2
from sonatype_iq_api_client.models.api_application_list_dto import ApiApplicationListDTO
from sonatype_iq_api_client.models.api_application_report_dtov2 import ApiApplicationReportDTOV2
from sonatype_iq_api_client.models.api_application_tag_dto import ApiApplicationTagDTO
from sonatype_iq_api_client.models.api_application_violation_dtov2 import ApiApplicationViolationDTOV2
from sonatype_iq_api_client.models.api_application_violation_list_dtov2 import ApiApplicationViolationListDTOV2
from sonatype_iq_api_client.models.api_application_waiver_dto import ApiApplicationWaiverDTO
from sonatype_iq_api_client.models.api_artifactory_connection_dto import ApiArtifactoryConnectionDTO
from sonatype_iq_api_client.models.api_artifactory_connection_status_request_dto import ApiArtifactoryConnectionStatusRequestDTO
from sonatype_iq_api_client.models.api_artifactory_connection_status_response_dto import ApiArtifactoryConnectionStatusResponseDTO
from sonatype_iq_api_client.models.api_auto_policy_waiver_dto import ApiAutoPolicyWaiverDTO
from sonatype_iq_api_client.models.api_auto_policy_waiver_revocation_dto import ApiAutoPolicyWaiverRevocationDTO
from sonatype_iq_api_client.models.api_auto_policy_waiver_status_dto import ApiAutoPolicyWaiverStatusDTO
from sonatype_iq_api_client.models.api_component_change_action_dto import ApiComponentChangeActionDTO
from sonatype_iq_api_client.models.api_component_dtov2 import ApiComponentDTOV2
from sonatype_iq_api_client.models.api_component_details_dtov2 import ApiComponentDetailsDTOV2
from sonatype_iq_api_client.models.api_component_details_request_dtov2 import ApiComponentDetailsRequestDTOV2
from sonatype_iq_api_client.models.api_component_details_result_dtov2 import ApiComponentDetailsResultDTOV2
from sonatype_iq_api_client.models.api_component_evaluation_request_dtov2 import ApiComponentEvaluationRequestDTOV2
from sonatype_iq_api_client.models.api_component_evaluation_result_dtov2 import ApiComponentEvaluationResultDTOV2
from sonatype_iq_api_client.models.api_component_evaluation_ticket_dtov2 import ApiComponentEvaluationTicketDTOV2
from sonatype_iq_api_client.models.api_component_identifier_dtov2 import ApiComponentIdentifierDTOV2
from sonatype_iq_api_client.models.api_component_or_purl_identifier_dtov2 import ApiComponentOrPurlIdentifierDTOV2
from sonatype_iq_api_client.models.api_component_policy_violation_dto import ApiComponentPolicyViolationDTO
from sonatype_iq_api_client.models.api_component_policy_violation_list_dtov2 import ApiComponentPolicyViolationListDTOV2
from sonatype_iq_api_client.models.api_component_policy_waivers_dto import ApiComponentPolicyWaiversDTO
from sonatype_iq_api_client.models.api_component_project_data_dto import ApiComponentProjectDataDTO
from sonatype_iq_api_client.models.api_component_project_metadata_dto import ApiComponentProjectMetadataDTO
from sonatype_iq_api_client.models.api_component_project_scm_dto import ApiComponentProjectScmDTO
from sonatype_iq_api_client.models.api_component_project_scm_details_dto import ApiComponentProjectScmDetailsDTO
from sonatype_iq_api_client.models.api_component_project_scm_metadata_dto import ApiComponentProjectScmMetadataDTO
from sonatype_iq_api_client.models.api_component_released_from_quarantine_dto import ApiComponentReleasedFromQuarantineDTO
from sonatype_iq_api_client.models.api_component_remediation_dto import ApiComponentRemediationDTO
from sonatype_iq_api_client.models.api_component_remediation_value_dto import ApiComponentRemediationValueDTO
from sonatype_iq_api_client.models.api_component_transitive_policy_violations_dto import ApiComponentTransitivePolicyViolationsDTO
from sonatype_iq_api_client.models.api_component_waivers_dto import ApiComponentWaiversDTO
from sonatype_iq_api_client.models.api_components_in_quarantine_dto import ApiComponentsInQuarantineDTO
from sonatype_iq_api_client.models.api_composite_source_control_dto import ApiCompositeSourceControlDTO
from sonatype_iq_api_client.models.api_composite_value_dto_boolean import ApiCompositeValueDTOBoolean
from sonatype_iq_api_client.models.api_composite_value_dto_string import ApiCompositeValueDTOString
from sonatype_iq_api_client.models.api_condition_fact_reason_dto import ApiConditionFactReasonDTO
from sonatype_iq_api_client.models.api_constraint_fact_dto import ApiConstraintFactDTO
from sonatype_iq_api_client.models.api_constraint_violation_dto import ApiConstraintViolationDTO
from sonatype_iq_api_client.models.api_constraint_violation_reason_dto import ApiConstraintViolationReasonDTO
from sonatype_iq_api_client.models.api_cross_stage_violation_dtov2 import ApiCrossStageViolationDTOV2
from sonatype_iq_api_client.models.api_crowd_configuration_dto import ApiCrowdConfigurationDTO
from sonatype_iq_api_client.models.api_data_retention_policies_dto import ApiDataRetentionPoliciesDTO
from sonatype_iq_api_client.models.api_dependency_data_dto import ApiDependencyDataDTO
from sonatype_iq_api_client.models.api_dependency_tree_node_dto import ApiDependencyTreeNodeDTO
from sonatype_iq_api_client.models.api_dependency_tree_response_dto import ApiDependencyTreeResponseDTO
from sonatype_iq_api_client.models.api_enhanced_policy_violation_dtov2 import ApiEnhancedPolicyViolationDTOV2
from sonatype_iq_api_client.models.api_evaluation_result_counter_dto import ApiEvaluationResultCounterDTO
from sonatype_iq_api_client.models.api_firewall_metrics_result_dto import ApiFirewallMetricsResultDTO
from sonatype_iq_api_client.models.api_firewall_quarantine_summary_dto import ApiFirewallQuarantineSummaryDTO
from sonatype_iq_api_client.models.api_firewall_release_quarantine_config_dto import ApiFirewallReleaseQuarantineConfigDTO
from sonatype_iq_api_client.models.api_firewall_release_quarantine_summary_dto import ApiFirewallReleaseQuarantineSummaryDTO
from sonatype_iq_api_client.models.api_global_information_dtov2 import ApiGlobalInformationDTOV2
from sonatype_iq_api_client.models.api_hash_component_identifier_dto import ApiHashComponentIdentifierDTO
from sonatype_iq_api_client.models.api_hash_component_identifiers_dto import ApiHashComponentIdentifiersDTO
from sonatype_iq_api_client.models.api_jira_configuration_dto import ApiJiraConfigurationDTO
from sonatype_iq_api_client.models.api_label_dto import ApiLabelDTO
from sonatype_iq_api_client.models.api_license_dto import ApiLicenseDTO
from sonatype_iq_api_client.models.api_license_data_dto import ApiLicenseDataDTO
from sonatype_iq_api_client.models.api_license_data_dtov2 import ApiLicenseDataDTOV2
from sonatype_iq_api_client.models.api_license_legal_application_report_dto import ApiLicenseLegalApplicationReportDTO
from sonatype_iq_api_client.models.api_license_legal_component_dto import ApiLicenseLegalComponentDTO
from sonatype_iq_api_client.models.api_license_legal_component_report_dto import ApiLicenseLegalComponentReportDTO
from sonatype_iq_api_client.models.api_license_legal_copyright_dto import ApiLicenseLegalCopyrightDTO
from sonatype_iq_api_client.models.api_license_legal_data_dto import ApiLicenseLegalDataDTO
from sonatype_iq_api_client.models.api_license_legal_file_dto import ApiLicenseLegalFileDTO
from sonatype_iq_api_client.models.api_license_legal_metadata_dto import ApiLicenseLegalMetadataDTO
from sonatype_iq_api_client.models.api_license_legal_obligation_dto import ApiLicenseLegalObligationDTO
from sonatype_iq_api_client.models.api_license_legal_stage_scan_dto import ApiLicenseLegalStageScanDTO
from sonatype_iq_api_client.models.api_license_threat_dtov2 import ApiLicenseThreatDTOV2
from sonatype_iq_api_client.models.api_licensed_solution_dto import ApiLicensedSolutionDTO
from sonatype_iq_api_client.models.api_mail_configuration_dto import ApiMailConfigurationDTO
from sonatype_iq_api_client.models.api_malware_component_evaluation_request import ApiMalwareComponentEvaluationRequest
from sonatype_iq_api_client.models.api_malware_component_evaluation_request_list import ApiMalwareComponentEvaluationRequestList
from sonatype_iq_api_client.models.api_match_state_summary_dtov2 import ApiMatchStateSummaryDTOV2
from sonatype_iq_api_client.models.api_member_dto import ApiMemberDTO
from sonatype_iq_api_client.models.api_metrics_reporting_query_dtov2 import ApiMetricsReportingQueryDTOV2
from sonatype_iq_api_client.models.api_move_application_response_dtov2 import ApiMoveApplicationResponseDTOV2
from sonatype_iq_api_client.models.api_organization_dto import ApiOrganizationDTO
from sonatype_iq_api_client.models.api_organization_list_dto import ApiOrganizationListDTO
from sonatype_iq_api_client.models.api_owner_artifactory_connection_dto import ApiOwnerArtifactoryConnectionDTO
from sonatype_iq_api_client.models.api_owner_dto import ApiOwnerDTO
from sonatype_iq_api_client.models.api_page_result_prioritized_component import ApiPageResultPrioritizedComponent
from sonatype_iq_api_client.models.api_policy_dto import ApiPolicyDTO
from sonatype_iq_api_client.models.api_policy_list_dto import ApiPolicyListDTO
from sonatype_iq_api_client.models.api_policy_violation_dtov2 import ApiPolicyViolationDTOV2
from sonatype_iq_api_client.models.api_policy_violation_diff_dto import ApiPolicyViolationDiffDTO
from sonatype_iq_api_client.models.api_policy_violation_for_diff_dto import ApiPolicyViolationForDiffDTO
from sonatype_iq_api_client.models.api_policy_violation_stage_dto import ApiPolicyViolationStageDTO
from sonatype_iq_api_client.models.api_policy_waiver_dto import ApiPolicyWaiverDTO
from sonatype_iq_api_client.models.api_policy_waiver_reason_dto import ApiPolicyWaiverReasonDTO
from sonatype_iq_api_client.models.api_policy_waivers_applicable_to_violation_dto import ApiPolicyWaiversApplicableToViolationDTO
from sonatype_iq_api_client.models.api_promote_scan_request_dtov2 import ApiPromoteScanRequestDTOV2
from sonatype_iq_api_client.models.api_proxy_server_configuration_dto import ApiProxyServerConfigurationDTO
from sonatype_iq_api_client.models.api_pull_request_result import ApiPullRequestResult
from sonatype_iq_api_client.models.api_pull_request_results import ApiPullRequestResults
from sonatype_iq_api_client.models.api_report_component_dtov2 import ApiReportComponentDTOV2
from sonatype_iq_api_client.models.api_report_component_policy_violations_dtov2 import ApiReportComponentPolicyViolationsDTOV2
from sonatype_iq_api_client.models.api_report_constraint_condition_dtov2 import ApiReportConstraintConditionDTOV2
from sonatype_iq_api_client.models.api_report_constraint_violation_dtov2 import ApiReportConstraintViolationDTOV2
from sonatype_iq_api_client.models.api_report_history_dto import ApiReportHistoryDTO
from sonatype_iq_api_client.models.api_report_policy_data_dtov2 import ApiReportPolicyDataDTOV2
from sonatype_iq_api_client.models.api_report_policy_violation_dtov2 import ApiReportPolicyViolationDTOV2
from sonatype_iq_api_client.models.api_report_raw_data_dtov2 import ApiReportRawDataDTOV2
from sonatype_iq_api_client.models.api_report_results_dto import ApiReportResultsDTO
from sonatype_iq_api_client.models.api_report_retention_policies_dto import ApiReportRetentionPoliciesDTO
from sonatype_iq_api_client.models.api_report_retention_policy_dto import ApiReportRetentionPolicyDTO
from sonatype_iq_api_client.models.api_repository_component_dto import ApiRepositoryComponentDTO
from sonatype_iq_api_client.models.api_repository_component_evaluation_request import ApiRepositoryComponentEvaluationRequest
from sonatype_iq_api_client.models.api_repository_component_evaluation_request_list import ApiRepositoryComponentEvaluationRequestList
from sonatype_iq_api_client.models.api_repository_component_evaluation_result import ApiRepositoryComponentEvaluationResult
from sonatype_iq_api_client.models.api_repository_component_evaluation_result_list import ApiRepositoryComponentEvaluationResultList
from sonatype_iq_api_client.models.api_repository_component_path import ApiRepositoryComponentPath
from sonatype_iq_api_client.models.api_repository_component_policy_violation_dto import ApiRepositoryComponentPolicyViolationDTO
from sonatype_iq_api_client.models.api_repository_components_in_quarantine_dto import ApiRepositoryComponentsInQuarantineDTO
from sonatype_iq_api_client.models.api_repository_container_dto import ApiRepositoryContainerDTO
from sonatype_iq_api_client.models.api_repository_dto import ApiRepositoryDTO
from sonatype_iq_api_client.models.api_repository_list_dto import ApiRepositoryListDTO
from sonatype_iq_api_client.models.api_repository_manager_dto import ApiRepositoryManagerDTO
from sonatype_iq_api_client.models.api_repository_manager_list_dto import ApiRepositoryManagerListDTO
from sonatype_iq_api_client.models.api_repository_path_response_dto import ApiRepositoryPathResponseDTO
from sonatype_iq_api_client.models.api_repository_path_versions import ApiRepositoryPathVersions
from sonatype_iq_api_client.models.api_repository_waiver_dto import ApiRepositoryWaiverDTO
from sonatype_iq_api_client.models.api_request_policy_waiver_dto import ApiRequestPolicyWaiverDTO
from sonatype_iq_api_client.models.api_reverse_proxy_authentication_configuration_dto import ApiReverseProxyAuthenticationConfigurationDTO
from sonatype_iq_api_client.models.api_role_dto import ApiRoleDTO
from sonatype_iq_api_client.models.api_role_list_dto import ApiRoleListDTO
from sonatype_iq_api_client.models.api_role_member_mapping_dto import ApiRoleMemberMappingDTO
from sonatype_iq_api_client.models.api_role_member_mapping_list_dto import ApiRoleMemberMappingListDTO
from sonatype_iq_api_client.models.api_saml_configuration_dto import ApiSamlConfigurationDTO
from sonatype_iq_api_client.models.api_saml_configuration_response_dto import ApiSamlConfigurationResponseDTO
from sonatype_iq_api_client.models.api_sbom_status_dto import ApiSbomStatusDTO
from sonatype_iq_api_client.models.api_search_criteria_dtov2 import ApiSearchCriteriaDTOV2
from sonatype_iq_api_client.models.api_search_result_dtov2 import ApiSearchResultDTOV2
from sonatype_iq_api_client.models.api_search_results_dtov2 import ApiSearchResultsDTOV2
from sonatype_iq_api_client.models.api_security_data_dto import ApiSecurityDataDTO
from sonatype_iq_api_client.models.api_security_issue_analysis_dto import ApiSecurityIssueAnalysisDTO
from sonatype_iq_api_client.models.api_security_issue_dto import ApiSecurityIssueDTO
from sonatype_iq_api_client.models.api_security_vulnerability_override_dtov2 import ApiSecurityVulnerabilityOverrideDTOV2
from sonatype_iq_api_client.models.api_security_vulnerability_override_response_dtov2 import ApiSecurityVulnerabilityOverrideResponseDTOV2
from sonatype_iq_api_client.models.api_source_control_configuration_dto import ApiSourceControlConfigurationDTO
from sonatype_iq_api_client.models.api_source_control_dto import ApiSourceControlDTO
from sonatype_iq_api_client.models.api_source_control_evaluation_request_dto import ApiSourceControlEvaluationRequestDTO
from sonatype_iq_api_client.models.api_stage_policy_violation_component_dto import ApiStagePolicyViolationComponentDTO
from sonatype_iq_api_client.models.api_stale_application_evaluation_dto import ApiStaleApplicationEvaluationDTO
from sonatype_iq_api_client.models.api_stale_evaluation_stage_dto import ApiStaleEvaluationStageDTO
from sonatype_iq_api_client.models.api_stale_evaluations_dto import ApiStaleEvaluationsDTO
from sonatype_iq_api_client.models.api_stale_repository_evaluation_dto import ApiStaleRepositoryEvaluationDTO
from sonatype_iq_api_client.models.api_stale_waiver_dto import ApiStaleWaiverDTO
from sonatype_iq_api_client.models.api_stale_waivers_response_dto import ApiStaleWaiversResponseDTO
from sonatype_iq_api_client.models.api_status_dto import ApiStatusDTO
from sonatype_iq_api_client.models.api_success_metrics_retention_policy_dto import ApiSuccessMetricsRetentionPolicyDTO
from sonatype_iq_api_client.models.api_suggested_version_change_option_dto import ApiSuggestedVersionChangeOptionDTO
from sonatype_iq_api_client.models.api_tag_dto import ApiTagDTO
from sonatype_iq_api_client.models.api_third_party_scan_result_dto import ApiThirdPartyScanResultDTO
from sonatype_iq_api_client.models.api_third_party_scan_ticket_dto import ApiThirdPartyScanTicketDTO
from sonatype_iq_api_client.models.api_user_dto import ApiUserDTO
from sonatype_iq_api_client.models.api_user_list_dto import ApiUserListDTO
from sonatype_iq_api_client.models.api_user_token_dto import ApiUserTokenDTO
from sonatype_iq_api_client.models.api_user_token_exists_dto import ApiUserTokenExistsDTO
from sonatype_iq_api_client.models.api_version_change_option_dto import ApiVersionChangeOptionDTO
from sonatype_iq_api_client.models.api_waived_policy_violation_dto import ApiWaivedPolicyViolationDTO
from sonatype_iq_api_client.models.api_waiver_options_dto import ApiWaiverOptionsDTO
from sonatype_iq_api_client.models.applicable_context import ApplicableContext
from sonatype_iq_api_client.models.applicable_labels import ApplicableLabels
from sonatype_iq_api_client.models.applicable_tags_dto import ApplicableTagsDTO
from sonatype_iq_api_client.models.application_tag import ApplicationTag
from sonatype_iq_api_client.models.application_tags_by_owner_dto import ApplicationTagsByOwnerDTO
from sonatype_iq_api_client.models.applied_tags_dto import AppliedTagsDTO
from sonatype_iq_api_client.models.attachment_text import AttachmentText
from sonatype_iq_api_client.models.attribution_report_template_dto import AttributionReportTemplateDTO
from sonatype_iq_api_client.models.component_display_name import ComponentDisplayName
from sonatype_iq_api_client.models.component_display_name_part import ComponentDisplayNamePart
from sonatype_iq_api_client.models.component_fact import ComponentFact
from sonatype_iq_api_client.models.component_identifier import ComponentIdentifier
from sonatype_iq_api_client.models.component_locator import ComponentLocator
from sonatype_iq_api_client.models.component_obligation_attribution_dto import ComponentObligationAttributionDTO
from sonatype_iq_api_client.models.condition_fact import ConditionFact
from sonatype_iq_api_client.models.configuration_validation_result import ConfigurationValidationResult
from sonatype_iq_api_client.models.constraint_fact import ConstraintFact
from sonatype_iq_api_client.models.cwe_id import CweId
from sonatype_iq_api_client.models.development_prioritization_results import DevelopmentPrioritizationResults
from sonatype_iq_api_client.models.form_data_content_disposition import FormDataContentDisposition
from sonatype_iq_api_client.models.grouping_by_dto import GroupingByDTO
from sonatype_iq_api_client.models.ide_users_overview_dto import IdeUsersOverviewDTO
from sonatype_iq_api_client.models.import_sbom_request import ImportSbomRequest
from sonatype_iq_api_client.models.inner_source_data import InnerSourceData
from sonatype_iq_api_client.models.labels_by_owner import LabelsByOwner
from sonatype_iq_api_client.models.legal_source_link_dto import LegalSourceLinkDTO
from sonatype_iq_api_client.models.license import License
from sonatype_iq_api_client.models.license_obligation_dto import LicenseObligationDTO
from sonatype_iq_api_client.models.license_threat_group_dto import LicenseThreatGroupDTO
from sonatype_iq_api_client.models.malware_defense_data import MalwareDefenseData
from sonatype_iq_api_client.models.malware_defense_response_list import MalwareDefenseResponseList
from sonatype_iq_api_client.models.policy_alert import PolicyAlert
from sonatype_iq_api_client.models.policy_evaluation_result import PolicyEvaluationResult
from sonatype_iq_api_client.models.policy_fact import PolicyFact
from sonatype_iq_api_client.models.policy_owner import PolicyOwner
from sonatype_iq_api_client.models.policy_tag import PolicyTag
from sonatype_iq_api_client.models.prioritized_component import PrioritizedComponent
from sonatype_iq_api_client.models.reference_link import ReferenceLink
from sonatype_iq_api_client.models.root_cause import RootCause
from sonatype_iq_api_client.models.sbom_vulnerability_analysis_request import SBOMVulnerabilityAnalysisRequest
from sonatype_iq_api_client.models.sbom_component_dto import SbomComponentDTO
from sonatype_iq_api_client.models.sbom_component_list_dto import SbomComponentListDTO
from sonatype_iq_api_client.models.search_result_dto import SearchResultDTO
from sonatype_iq_api_client.models.search_result_item_dto import SearchResultItemDTO
from sonatype_iq_api_client.models.security_vulnerability_custom_data import SecurityVulnerabilityCustomData
from sonatype_iq_api_client.models.security_vulnerability_data import SecurityVulnerabilityData
from sonatype_iq_api_client.models.security_vulnerability_severity import SecurityVulnerabilitySeverity
from sonatype_iq_api_client.models.security_vulnerability_weakness import SecurityVulnerabilityWeakness
from sonatype_iq_api_client.models.stage_data import StageData
from sonatype_iq_api_client.models.swid import Swid
from sonatype_iq_api_client.models.system_config import SystemConfig
from sonatype_iq_api_client.models.system_config_property import SystemConfigProperty
from sonatype_iq_api_client.models.tags_by_owner_dto import TagsByOwnerDTO
from sonatype_iq_api_client.models.third_party_sbom_metadata_summary_dto import ThirdPartySbomMetadataSummaryDTO
from sonatype_iq_api_client.models.third_party_sbom_metadata_summary_list_dto import ThirdPartySbomMetadataSummaryListDTO
from sonatype_iq_api_client.models.trigger_reference import TriggerReference
from sonatype_iq_api_client.models.validation_result import ValidationResult
from sonatype_iq_api_client.models.vulnerability_analysis import VulnerabilityAnalysis
from sonatype_iq_api_client.models.vulnerability_source import VulnerabilitySource



# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.184.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictBool, StrictInt, StrictStr, field_validator
from typing import List, Optional
from typing_extensions import Annotated
from sonatype_iq_api_client.models.component_locator import ComponentLocator
from sonatype_iq_api_client.models.import_sbom_request import ImportSbomRequest
from sonatype_iq_api_client.models.sbom_vulnerability_analysis_request import SBOMVulnerabilityAnalysisRequest

from sonatype_iq_api_client.api_client import ApiClient, RequestSerialized
from sonatype_iq_api_client.api_response import ApiResponse
from sonatype_iq_api_client.rest import RESTResponseType


class SbomApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def delete_sbom_version(
        self,
        application_id: Annotated[StrictStr, Field(description="The internal id of the application")],
        version: Annotated[StrictStr, Field(description="URL Encoded version value of the sbom to be deleted")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """Delete sbom version

        Deletes a specific sbom version including it's original contents and updates

        :param application_id: The internal id of the application (required)
        :type application_id: str
        :param version: URL Encoded version value of the sbom to be deleted (required)
        :type version: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._delete_sbom_version_serialize(
            application_id=application_id,
            version=version,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
            '404': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def delete_sbom_version_with_http_info(
        self,
        application_id: Annotated[StrictStr, Field(description="The internal id of the application")],
        version: Annotated[StrictStr, Field(description="URL Encoded version value of the sbom to be deleted")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """Delete sbom version

        Deletes a specific sbom version including it's original contents and updates

        :param application_id: The internal id of the application (required)
        :type application_id: str
        :param version: URL Encoded version value of the sbom to be deleted (required)
        :type version: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._delete_sbom_version_serialize(
            application_id=application_id,
            version=version,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
            '404': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def delete_sbom_version_without_preload_content(
        self,
        application_id: Annotated[StrictStr, Field(description="The internal id of the application")],
        version: Annotated[StrictStr, Field(description="URL Encoded version value of the sbom to be deleted")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Delete sbom version

        Deletes a specific sbom version including it's original contents and updates

        :param application_id: The internal id of the application (required)
        :type application_id: str
        :param version: URL Encoded version value of the sbom to be deleted (required)
        :type version: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._delete_sbom_version_serialize(
            application_id=application_id,
            version=version,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
            '404': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _delete_sbom_version_serialize(
        self,
        application_id,
        version,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if application_id is not None:
            _path_params['applicationId'] = application_id
        if version is not None:
            _path_params['version'] = version
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter




        # authentication setting
        _auth_settings: List[str] = [
            'BasicAuth'
        ]

        return self.api_client.param_serialize(
            method='DELETE',
            resource_path='/api/v2/sbom/applications/{applicationId}/versions/{version}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def delete_vulnerability_analysis(
        self,
        application_id: Annotated[StrictStr, Field(description="The internal id of the application")],
        version: Annotated[StrictStr, Field(description="The version for a specific SBOM where the vulnerability is present")],
        ref_id: Annotated[StrictStr, Field(description="The vulnerability id of a vulnerability")],
        component_locator: Annotated[ComponentLocator, Field(description="Hash or packageUrl to identify the component")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """Deletes a Vulnerability analysis for a given component.

        Deletes a Vulnerability analysis for a given component.

        :param application_id: The internal id of the application (required)
        :type application_id: str
        :param version: The version for a specific SBOM where the vulnerability is present (required)
        :type version: str
        :param ref_id: The vulnerability id of a vulnerability (required)
        :type ref_id: str
        :param component_locator: Hash or packageUrl to identify the component (required)
        :type component_locator: ComponentLocator
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._delete_vulnerability_analysis_serialize(
            application_id=application_id,
            version=version,
            ref_id=ref_id,
            component_locator=component_locator,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
            '404': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def delete_vulnerability_analysis_with_http_info(
        self,
        application_id: Annotated[StrictStr, Field(description="The internal id of the application")],
        version: Annotated[StrictStr, Field(description="The version for a specific SBOM where the vulnerability is present")],
        ref_id: Annotated[StrictStr, Field(description="The vulnerability id of a vulnerability")],
        component_locator: Annotated[ComponentLocator, Field(description="Hash or packageUrl to identify the component")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """Deletes a Vulnerability analysis for a given component.

        Deletes a Vulnerability analysis for a given component.

        :param application_id: The internal id of the application (required)
        :type application_id: str
        :param version: The version for a specific SBOM where the vulnerability is present (required)
        :type version: str
        :param ref_id: The vulnerability id of a vulnerability (required)
        :type ref_id: str
        :param component_locator: Hash or packageUrl to identify the component (required)
        :type component_locator: ComponentLocator
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._delete_vulnerability_analysis_serialize(
            application_id=application_id,
            version=version,
            ref_id=ref_id,
            component_locator=component_locator,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
            '404': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def delete_vulnerability_analysis_without_preload_content(
        self,
        application_id: Annotated[StrictStr, Field(description="The internal id of the application")],
        version: Annotated[StrictStr, Field(description="The version for a specific SBOM where the vulnerability is present")],
        ref_id: Annotated[StrictStr, Field(description="The vulnerability id of a vulnerability")],
        component_locator: Annotated[ComponentLocator, Field(description="Hash or packageUrl to identify the component")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Deletes a Vulnerability analysis for a given component.

        Deletes a Vulnerability analysis for a given component.

        :param application_id: The internal id of the application (required)
        :type application_id: str
        :param version: The version for a specific SBOM where the vulnerability is present (required)
        :type version: str
        :param ref_id: The vulnerability id of a vulnerability (required)
        :type ref_id: str
        :param component_locator: Hash or packageUrl to identify the component (required)
        :type component_locator: ComponentLocator
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._delete_vulnerability_analysis_serialize(
            application_id=application_id,
            version=version,
            ref_id=ref_id,
            component_locator=component_locator,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
            '404': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _delete_vulnerability_analysis_serialize(
        self,
        application_id,
        version,
        ref_id,
        component_locator,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if application_id is not None:
            _path_params['applicationId'] = application_id
        if version is not None:
            _path_params['version'] = version
        if ref_id is not None:
            _path_params['refId'] = ref_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if component_locator is not None:
            _body_params = component_locator



        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'BasicAuth'
        ]

        return self.api_client.param_serialize(
            method='DELETE',
            resource_path='/api/v2/sbom/applications/{applicationId}/versions/{version}/vulnerability/{refId}/analysis',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_active_sbom_version_list_by_application(
        self,
        application_id: Annotated[StrictStr, Field(description="The internal id of the application")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """Gets a list of active sbom versions by application id

        Gets a list of active sbom versions by application id

        :param application_id: The internal id of the application (required)
        :type application_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_active_sbom_version_list_by_application_serialize(
            application_id=application_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_active_sbom_version_list_by_application_with_http_info(
        self,
        application_id: Annotated[StrictStr, Field(description="The internal id of the application")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """Gets a list of active sbom versions by application id

        Gets a list of active sbom versions by application id

        :param application_id: The internal id of the application (required)
        :type application_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_active_sbom_version_list_by_application_serialize(
            application_id=application_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_active_sbom_version_list_by_application_without_preload_content(
        self,
        application_id: Annotated[StrictStr, Field(description="The internal id of the application")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Gets a list of active sbom versions by application id

        Gets a list of active sbom versions by application id

        :param application_id: The internal id of the application (required)
        :type application_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_active_sbom_version_list_by_application_serialize(
            application_id=application_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_active_sbom_version_list_by_application_serialize(
        self,
        application_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if application_id is not None:
            _path_params['applicationId'] = application_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'BasicAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/v2/sbom/applications/{applicationId}/versions',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_import_status(
        self,
        application_id: Annotated[StrictStr, Field(description="The internal id of the application")],
        import_request_id: Annotated[StrictStr, Field(description="The id of the import request")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """Get sbom import status

        Gets status of a sbom import.

        :param application_id: The internal id of the application (required)
        :type application_id: str
        :param import_request_id: The id of the import request (required)
        :type import_request_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_import_status_serialize(
            application_id=application_id,
            import_request_id=import_request_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '404': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_import_status_with_http_info(
        self,
        application_id: Annotated[StrictStr, Field(description="The internal id of the application")],
        import_request_id: Annotated[StrictStr, Field(description="The id of the import request")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """Get sbom import status

        Gets status of a sbom import.

        :param application_id: The internal id of the application (required)
        :type application_id: str
        :param import_request_id: The id of the import request (required)
        :type import_request_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_import_status_serialize(
            application_id=application_id,
            import_request_id=import_request_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '404': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_import_status_without_preload_content(
        self,
        application_id: Annotated[StrictStr, Field(description="The internal id of the application")],
        import_request_id: Annotated[StrictStr, Field(description="The id of the import request")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get sbom import status

        Gets status of a sbom import.

        :param application_id: The internal id of the application (required)
        :type application_id: str
        :param import_request_id: The id of the import request (required)
        :type import_request_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_import_status_serialize(
            application_id=application_id,
            import_request_id=import_request_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '404': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_import_status_serialize(
        self,
        application_id,
        import_request_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if application_id is not None:
            _path_params['applicationId'] = application_id
        if import_request_id is not None:
            _path_params['importRequestId'] = import_request_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'BasicAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/v2/sbom/applications/{applicationId}/status/{importRequestId}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_sbom_components(
        self,
        application_id: Annotated[StrictStr, Field(description="The internal id of the application")],
        version: Annotated[StrictStr, Field(description="URL Encoded version value of the sbom to query its components")],
        vulnerability_threat_levels: Annotated[Optional[List[StrictStr]], Field(description="If provided, filter components by the given threat level on their vulnerabilities")] = None,
        dependency_types: Annotated[Optional[List[StrictStr]], Field(description="If provided, filter components by the given dependency types")] = None,
        component_name: Annotated[Optional[StrictStr], Field(description="If provided, filter components by the component name")] = None,
        sort_by: Annotated[Optional[StrictStr], Field(description="Criteria to sort the results. default = VULNERABILITIES")] = None,
        asc: Annotated[Optional[StrictBool], Field(description="Order mode ASC=true or DESC=false. default = false")] = None,
        page: Annotated[Optional[StrictInt], Field(description="Current page number. default = 1")] = None,
        page_size: Annotated[Optional[StrictInt], Field(description="Number of items to return by page. default = 50")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """Gets the components found in a specific sbom version

        Lists the components in a specific sbom version with data about vulnerabilities and licenses

        :param application_id: The internal id of the application (required)
        :type application_id: str
        :param version: URL Encoded version value of the sbom to query its components (required)
        :type version: str
        :param vulnerability_threat_levels: If provided, filter components by the given threat level on their vulnerabilities
        :type vulnerability_threat_levels: List[str]
        :param dependency_types: If provided, filter components by the given dependency types
        :type dependency_types: List[str]
        :param component_name: If provided, filter components by the component name
        :type component_name: str
        :param sort_by: Criteria to sort the results. default = VULNERABILITIES
        :type sort_by: str
        :param asc: Order mode ASC=true or DESC=false. default = false
        :type asc: bool
        :param page: Current page number. default = 1
        :type page: int
        :param page_size: Number of items to return by page. default = 50
        :type page_size: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_sbom_components_serialize(
            application_id=application_id,
            version=version,
            vulnerability_threat_levels=vulnerability_threat_levels,
            dependency_types=dependency_types,
            component_name=component_name,
            sort_by=sort_by,
            asc=asc,
            page=page,
            page_size=page_size,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_sbom_components_with_http_info(
        self,
        application_id: Annotated[StrictStr, Field(description="The internal id of the application")],
        version: Annotated[StrictStr, Field(description="URL Encoded version value of the sbom to query its components")],
        vulnerability_threat_levels: Annotated[Optional[List[StrictStr]], Field(description="If provided, filter components by the given threat level on their vulnerabilities")] = None,
        dependency_types: Annotated[Optional[List[StrictStr]], Field(description="If provided, filter components by the given dependency types")] = None,
        component_name: Annotated[Optional[StrictStr], Field(description="If provided, filter components by the component name")] = None,
        sort_by: Annotated[Optional[StrictStr], Field(description="Criteria to sort the results. default = VULNERABILITIES")] = None,
        asc: Annotated[Optional[StrictBool], Field(description="Order mode ASC=true or DESC=false. default = false")] = None,
        page: Annotated[Optional[StrictInt], Field(description="Current page number. default = 1")] = None,
        page_size: Annotated[Optional[StrictInt], Field(description="Number of items to return by page. default = 50")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """Gets the components found in a specific sbom version

        Lists the components in a specific sbom version with data about vulnerabilities and licenses

        :param application_id: The internal id of the application (required)
        :type application_id: str
        :param version: URL Encoded version value of the sbom to query its components (required)
        :type version: str
        :param vulnerability_threat_levels: If provided, filter components by the given threat level on their vulnerabilities
        :type vulnerability_threat_levels: List[str]
        :param dependency_types: If provided, filter components by the given dependency types
        :type dependency_types: List[str]
        :param component_name: If provided, filter components by the component name
        :type component_name: str
        :param sort_by: Criteria to sort the results. default = VULNERABILITIES
        :type sort_by: str
        :param asc: Order mode ASC=true or DESC=false. default = false
        :type asc: bool
        :param page: Current page number. default = 1
        :type page: int
        :param page_size: Number of items to return by page. default = 50
        :type page_size: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_sbom_components_serialize(
            application_id=application_id,
            version=version,
            vulnerability_threat_levels=vulnerability_threat_levels,
            dependency_types=dependency_types,
            component_name=component_name,
            sort_by=sort_by,
            asc=asc,
            page=page,
            page_size=page_size,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_sbom_components_without_preload_content(
        self,
        application_id: Annotated[StrictStr, Field(description="The internal id of the application")],
        version: Annotated[StrictStr, Field(description="URL Encoded version value of the sbom to query its components")],
        vulnerability_threat_levels: Annotated[Optional[List[StrictStr]], Field(description="If provided, filter components by the given threat level on their vulnerabilities")] = None,
        dependency_types: Annotated[Optional[List[StrictStr]], Field(description="If provided, filter components by the given dependency types")] = None,
        component_name: Annotated[Optional[StrictStr], Field(description="If provided, filter components by the component name")] = None,
        sort_by: Annotated[Optional[StrictStr], Field(description="Criteria to sort the results. default = VULNERABILITIES")] = None,
        asc: Annotated[Optional[StrictBool], Field(description="Order mode ASC=true or DESC=false. default = false")] = None,
        page: Annotated[Optional[StrictInt], Field(description="Current page number. default = 1")] = None,
        page_size: Annotated[Optional[StrictInt], Field(description="Number of items to return by page. default = 50")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Gets the components found in a specific sbom version

        Lists the components in a specific sbom version with data about vulnerabilities and licenses

        :param application_id: The internal id of the application (required)
        :type application_id: str
        :param version: URL Encoded version value of the sbom to query its components (required)
        :type version: str
        :param vulnerability_threat_levels: If provided, filter components by the given threat level on their vulnerabilities
        :type vulnerability_threat_levels: List[str]
        :param dependency_types: If provided, filter components by the given dependency types
        :type dependency_types: List[str]
        :param component_name: If provided, filter components by the component name
        :type component_name: str
        :param sort_by: Criteria to sort the results. default = VULNERABILITIES
        :type sort_by: str
        :param asc: Order mode ASC=true or DESC=false. default = false
        :type asc: bool
        :param page: Current page number. default = 1
        :type page: int
        :param page_size: Number of items to return by page. default = 50
        :type page_size: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_sbom_components_serialize(
            application_id=application_id,
            version=version,
            vulnerability_threat_levels=vulnerability_threat_levels,
            dependency_types=dependency_types,
            component_name=component_name,
            sort_by=sort_by,
            asc=asc,
            page=page,
            page_size=page_size,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_sbom_components_serialize(
        self,
        application_id,
        version,
        vulnerability_threat_levels,
        dependency_types,
        component_name,
        sort_by,
        asc,
        page,
        page_size,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
            'vulnerabilityThreatLevels': 'multi',
            'dependencyTypes': 'multi',
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if application_id is not None:
            _path_params['applicationId'] = application_id
        if version is not None:
            _path_params['version'] = version
        # process the query parameters
        if vulnerability_threat_levels is not None:
            
            _query_params.append(('vulnerabilityThreatLevels', vulnerability_threat_levels))
            
        if dependency_types is not None:
            
            _query_params.append(('dependencyTypes', dependency_types))
            
        if component_name is not None:
            
            _query_params.append(('componentName', component_name))
            
        if sort_by is not None:
            
            _query_params.append(('sortBy', sort_by))
            
        if asc is not None:
            
            _query_params.append(('asc', asc))
            
        if page is not None:
            
            _query_params.append(('page', page))
            
        if page_size is not None:
            
            _query_params.append(('pageSize', page_size))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'BasicAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/v2/sbom/applications/{applicationId}/versions/{version}/components',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_sbom_metadata_summary_for_application(
        self,
        application_id: Annotated[StrictStr, Field(description="The internal id of the application")],
        sort_by_date: Annotated[Optional[StrictStr], Field(description="Sort results by import date. Allowed values [asc|desc]. default = asc")] = None,
        page_size: Annotated[Optional[StrictInt], Field(description="Number of items to return by page. default = 10")] = None,
        page: Annotated[Optional[StrictInt], Field(description="Current page number. default = 1")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """Gets a paginated list of SBOMs for an application

        Gets a paginated list of SBOMs for an application

        :param application_id: The internal id of the application (required)
        :type application_id: str
        :param sort_by_date: Sort results by import date. Allowed values [asc|desc]. default = asc
        :type sort_by_date: str
        :param page_size: Number of items to return by page. default = 10
        :type page_size: int
        :param page: Current page number. default = 1
        :type page: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_sbom_metadata_summary_for_application_serialize(
            application_id=application_id,
            sort_by_date=sort_by_date,
            page_size=page_size,
            page=page,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_sbom_metadata_summary_for_application_with_http_info(
        self,
        application_id: Annotated[StrictStr, Field(description="The internal id of the application")],
        sort_by_date: Annotated[Optional[StrictStr], Field(description="Sort results by import date. Allowed values [asc|desc]. default = asc")] = None,
        page_size: Annotated[Optional[StrictInt], Field(description="Number of items to return by page. default = 10")] = None,
        page: Annotated[Optional[StrictInt], Field(description="Current page number. default = 1")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """Gets a paginated list of SBOMs for an application

        Gets a paginated list of SBOMs for an application

        :param application_id: The internal id of the application (required)
        :type application_id: str
        :param sort_by_date: Sort results by import date. Allowed values [asc|desc]. default = asc
        :type sort_by_date: str
        :param page_size: Number of items to return by page. default = 10
        :type page_size: int
        :param page: Current page number. default = 1
        :type page: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_sbom_metadata_summary_for_application_serialize(
            application_id=application_id,
            sort_by_date=sort_by_date,
            page_size=page_size,
            page=page,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_sbom_metadata_summary_for_application_without_preload_content(
        self,
        application_id: Annotated[StrictStr, Field(description="The internal id of the application")],
        sort_by_date: Annotated[Optional[StrictStr], Field(description="Sort results by import date. Allowed values [asc|desc]. default = asc")] = None,
        page_size: Annotated[Optional[StrictInt], Field(description="Number of items to return by page. default = 10")] = None,
        page: Annotated[Optional[StrictInt], Field(description="Current page number. default = 1")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Gets a paginated list of SBOMs for an application

        Gets a paginated list of SBOMs for an application

        :param application_id: The internal id of the application (required)
        :type application_id: str
        :param sort_by_date: Sort results by import date. Allowed values [asc|desc]. default = asc
        :type sort_by_date: str
        :param page_size: Number of items to return by page. default = 10
        :type page_size: int
        :param page: Current page number. default = 1
        :type page: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_sbom_metadata_summary_for_application_serialize(
            application_id=application_id,
            sort_by_date=sort_by_date,
            page_size=page_size,
            page=page,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_sbom_metadata_summary_for_application_serialize(
        self,
        application_id,
        sort_by_date,
        page_size,
        page,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if application_id is not None:
            _path_params['applicationId'] = application_id
        # process the query parameters
        if sort_by_date is not None:
            
            _query_params.append(('sortByDate', sort_by_date))
            
        if page_size is not None:
            
            _query_params.append(('pageSize', page_size))
            
        if page is not None:
            
            _query_params.append(('page', page))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'BasicAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/v2/sbom/applications/{applicationId}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_sbom_version(
        self,
        application_id: Annotated[StrictStr, Field(description="The internal id of the application")],
        version: Annotated[StrictStr, Field(description="URL Encoded version value of the sbom")],
        state: Annotated[Optional[StrictStr], Field(description="The state of the sbom version. Allowed values [original|current]. default = current")] = None,
        specification: Annotated[Optional[StrictStr], Field(description="Target specification of the sbom. Allowed values [cyclonedx1.6|cyclonedx1.5|spdx2.3]. default = cyclonedx1.6")] = None,
        accept: Annotated[Optional[StrictStr], Field(description="Output format(json/xml) of the sbom. Changing the output format only applicable when downloading the current form of the SBOM. The original sbom will always return in the original form that it was ingested. When requesting `current` form and if this header value is not present the sbom will be returned in its original ingested format. Allowed values {'application/json'|'application/xml'}. default = null")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """Gets a sbom version

        Downloads a specific sbom version in its original or current form

        :param application_id: The internal id of the application (required)
        :type application_id: str
        :param version: URL Encoded version value of the sbom (required)
        :type version: str
        :param state: The state of the sbom version. Allowed values [original|current]. default = current
        :type state: str
        :param specification: Target specification of the sbom. Allowed values [cyclonedx1.6|cyclonedx1.5|spdx2.3]. default = cyclonedx1.6
        :type specification: str
        :param accept: Output format(json/xml) of the sbom. Changing the output format only applicable when downloading the current form of the SBOM. The original sbom will always return in the original form that it was ingested. When requesting `current` form and if this header value is not present the sbom will be returned in its original ingested format. Allowed values {'application/json'|'application/xml'}. default = null
        :type accept: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_sbom_version_serialize(
            application_id=application_id,
            version=version,
            state=state,
            specification=specification,
            accept=accept,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '404': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_sbom_version_with_http_info(
        self,
        application_id: Annotated[StrictStr, Field(description="The internal id of the application")],
        version: Annotated[StrictStr, Field(description="URL Encoded version value of the sbom")],
        state: Annotated[Optional[StrictStr], Field(description="The state of the sbom version. Allowed values [original|current]. default = current")] = None,
        specification: Annotated[Optional[StrictStr], Field(description="Target specification of the sbom. Allowed values [cyclonedx1.6|cyclonedx1.5|spdx2.3]. default = cyclonedx1.6")] = None,
        accept: Annotated[Optional[StrictStr], Field(description="Output format(json/xml) of the sbom. Changing the output format only applicable when downloading the current form of the SBOM. The original sbom will always return in the original form that it was ingested. When requesting `current` form and if this header value is not present the sbom will be returned in its original ingested format. Allowed values {'application/json'|'application/xml'}. default = null")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """Gets a sbom version

        Downloads a specific sbom version in its original or current form

        :param application_id: The internal id of the application (required)
        :type application_id: str
        :param version: URL Encoded version value of the sbom (required)
        :type version: str
        :param state: The state of the sbom version. Allowed values [original|current]. default = current
        :type state: str
        :param specification: Target specification of the sbom. Allowed values [cyclonedx1.6|cyclonedx1.5|spdx2.3]. default = cyclonedx1.6
        :type specification: str
        :param accept: Output format(json/xml) of the sbom. Changing the output format only applicable when downloading the current form of the SBOM. The original sbom will always return in the original form that it was ingested. When requesting `current` form and if this header value is not present the sbom will be returned in its original ingested format. Allowed values {'application/json'|'application/xml'}. default = null
        :type accept: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_sbom_version_serialize(
            application_id=application_id,
            version=version,
            state=state,
            specification=specification,
            accept=accept,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '404': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_sbom_version_without_preload_content(
        self,
        application_id: Annotated[StrictStr, Field(description="The internal id of the application")],
        version: Annotated[StrictStr, Field(description="URL Encoded version value of the sbom")],
        state: Annotated[Optional[StrictStr], Field(description="The state of the sbom version. Allowed values [original|current]. default = current")] = None,
        specification: Annotated[Optional[StrictStr], Field(description="Target specification of the sbom. Allowed values [cyclonedx1.6|cyclonedx1.5|spdx2.3]. default = cyclonedx1.6")] = None,
        accept: Annotated[Optional[StrictStr], Field(description="Output format(json/xml) of the sbom. Changing the output format only applicable when downloading the current form of the SBOM. The original sbom will always return in the original form that it was ingested. When requesting `current` form and if this header value is not present the sbom will be returned in its original ingested format. Allowed values {'application/json'|'application/xml'}. default = null")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Gets a sbom version

        Downloads a specific sbom version in its original or current form

        :param application_id: The internal id of the application (required)
        :type application_id: str
        :param version: URL Encoded version value of the sbom (required)
        :type version: str
        :param state: The state of the sbom version. Allowed values [original|current]. default = current
        :type state: str
        :param specification: Target specification of the sbom. Allowed values [cyclonedx1.6|cyclonedx1.5|spdx2.3]. default = cyclonedx1.6
        :type specification: str
        :param accept: Output format(json/xml) of the sbom. Changing the output format only applicable when downloading the current form of the SBOM. The original sbom will always return in the original form that it was ingested. When requesting `current` form and if this header value is not present the sbom will be returned in its original ingested format. Allowed values {'application/json'|'application/xml'}. default = null
        :type accept: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_sbom_version_serialize(
            application_id=application_id,
            version=version,
            state=state,
            specification=specification,
            accept=accept,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '404': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_sbom_version_serialize(
        self,
        application_id,
        version,
        state,
        specification,
        accept,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if application_id is not None:
            _path_params['applicationId'] = application_id
        if version is not None:
            _path_params['version'] = version
        # process the query parameters
        if state is not None:
            
            _query_params.append(('state', state))
            
        if specification is not None:
            
            _query_params.append(('specification', specification))
            
        # process the header parameters
        if accept is not None:
            _header_params['Accept'] = accept
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json|application/xml'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'BasicAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/v2/sbom/applications/{applicationId}/versions/{version}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def import_sbom(
        self,
        enable_binary_import: Annotated[Optional[StrictBool], Field(description="Enable importing as a binary file. default = false")] = None,
        import_sbom_request: Optional[ImportSbomRequest] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """Import a new sbom version

        Imports a new sbom version to an existing application

        :param enable_binary_import: Enable importing as a binary file. default = false
        :type enable_binary_import: bool
        :param import_sbom_request:
        :type import_sbom_request: ImportSbomRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._import_sbom_serialize(
            enable_binary_import=enable_binary_import,
            import_sbom_request=import_sbom_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '202': None,
            '400': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def import_sbom_with_http_info(
        self,
        enable_binary_import: Annotated[Optional[StrictBool], Field(description="Enable importing as a binary file. default = false")] = None,
        import_sbom_request: Optional[ImportSbomRequest] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """Import a new sbom version

        Imports a new sbom version to an existing application

        :param enable_binary_import: Enable importing as a binary file. default = false
        :type enable_binary_import: bool
        :param import_sbom_request:
        :type import_sbom_request: ImportSbomRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._import_sbom_serialize(
            enable_binary_import=enable_binary_import,
            import_sbom_request=import_sbom_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '202': None,
            '400': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def import_sbom_without_preload_content(
        self,
        enable_binary_import: Annotated[Optional[StrictBool], Field(description="Enable importing as a binary file. default = false")] = None,
        import_sbom_request: Optional[ImportSbomRequest] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Import a new sbom version

        Imports a new sbom version to an existing application

        :param enable_binary_import: Enable importing as a binary file. default = false
        :type enable_binary_import: bool
        :param import_sbom_request:
        :type import_sbom_request: ImportSbomRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._import_sbom_serialize(
            enable_binary_import=enable_binary_import,
            import_sbom_request=import_sbom_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '202': None,
            '400': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _import_sbom_serialize(
        self,
        enable_binary_import,
        import_sbom_request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if enable_binary_import is not None:
            
            _query_params.append(('enableBinaryImport', enable_binary_import))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if import_sbom_request is not None:
            _body_params = import_sbom_request


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'BasicAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/api/v2/sbom/import',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def save_vulnerability_analysis(
        self,
        application_id: Annotated[StrictStr, Field(description="The internal id of the application")],
        version: Annotated[StrictStr, Field(description="The version for a specific SBOM where the vulnerability is present")],
        ref_id: Annotated[StrictStr, Field(description="The vulnerability id of a vulnerability")],
        sbom_vulnerability_analysis_request: Annotated[SBOMVulnerabilityAnalysisRequest, Field(description="Vulnerability analysis details with component information")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """Updates a vulnerability analysis annotation for a specific SBOM vulnerability

        Updates a vulnerability analysis annotation for a specific SBOM vulnerability

        :param application_id: The internal id of the application (required)
        :type application_id: str
        :param version: The version for a specific SBOM where the vulnerability is present (required)
        :type version: str
        :param ref_id: The vulnerability id of a vulnerability (required)
        :type ref_id: str
        :param sbom_vulnerability_analysis_request: Vulnerability analysis details with component information (required)
        :type sbom_vulnerability_analysis_request: SBOMVulnerabilityAnalysisRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._save_vulnerability_analysis_serialize(
            application_id=application_id,
            version=version,
            ref_id=ref_id,
            sbom_vulnerability_analysis_request=sbom_vulnerability_analysis_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '404': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def save_vulnerability_analysis_with_http_info(
        self,
        application_id: Annotated[StrictStr, Field(description="The internal id of the application")],
        version: Annotated[StrictStr, Field(description="The version for a specific SBOM where the vulnerability is present")],
        ref_id: Annotated[StrictStr, Field(description="The vulnerability id of a vulnerability")],
        sbom_vulnerability_analysis_request: Annotated[SBOMVulnerabilityAnalysisRequest, Field(description="Vulnerability analysis details with component information")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """Updates a vulnerability analysis annotation for a specific SBOM vulnerability

        Updates a vulnerability analysis annotation for a specific SBOM vulnerability

        :param application_id: The internal id of the application (required)
        :type application_id: str
        :param version: The version for a specific SBOM where the vulnerability is present (required)
        :type version: str
        :param ref_id: The vulnerability id of a vulnerability (required)
        :type ref_id: str
        :param sbom_vulnerability_analysis_request: Vulnerability analysis details with component information (required)
        :type sbom_vulnerability_analysis_request: SBOMVulnerabilityAnalysisRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._save_vulnerability_analysis_serialize(
            application_id=application_id,
            version=version,
            ref_id=ref_id,
            sbom_vulnerability_analysis_request=sbom_vulnerability_analysis_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '404': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def save_vulnerability_analysis_without_preload_content(
        self,
        application_id: Annotated[StrictStr, Field(description="The internal id of the application")],
        version: Annotated[StrictStr, Field(description="The version for a specific SBOM where the vulnerability is present")],
        ref_id: Annotated[StrictStr, Field(description="The vulnerability id of a vulnerability")],
        sbom_vulnerability_analysis_request: Annotated[SBOMVulnerabilityAnalysisRequest, Field(description="Vulnerability analysis details with component information")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Updates a vulnerability analysis annotation for a specific SBOM vulnerability

        Updates a vulnerability analysis annotation for a specific SBOM vulnerability

        :param application_id: The internal id of the application (required)
        :type application_id: str
        :param version: The version for a specific SBOM where the vulnerability is present (required)
        :type version: str
        :param ref_id: The vulnerability id of a vulnerability (required)
        :type ref_id: str
        :param sbom_vulnerability_analysis_request: Vulnerability analysis details with component information (required)
        :type sbom_vulnerability_analysis_request: SBOMVulnerabilityAnalysisRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._save_vulnerability_analysis_serialize(
            application_id=application_id,
            version=version,
            ref_id=ref_id,
            sbom_vulnerability_analysis_request=sbom_vulnerability_analysis_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '404': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _save_vulnerability_analysis_serialize(
        self,
        application_id,
        version,
        ref_id,
        sbom_vulnerability_analysis_request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if application_id is not None:
            _path_params['applicationId'] = application_id
        if version is not None:
            _path_params['version'] = version
        if ref_id is not None:
            _path_params['refId'] = ref_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if sbom_vulnerability_analysis_request is not None:
            _body_params = sbom_vulnerability_analysis_request


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'BasicAuth'
        ]

        return self.api_client.param_serialize(
            method='PUT',
            resource_path='/api/v2/sbom/applications/{applicationId}/versions/{version}/vulnerability/{refId}/analysis',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )


